@@ -1,27 +1,19 @@
-from functools import reduce
-from functools import partial
-import operator
-import subprocess
-import itertools
-import re
 import concurrent.futures
-from collections.abc import Iterable
+import itertools
+import operator
+import re
+import subprocess
+from functools import partial
+from functools import reduce
+
 
 # basic
 class B:
-    def __init__(self, f=None): self.f = f
-class Pipe  (B): __ror__ = lambda self, x: self.f(x)        
+    def __init__(self, f=None, **kw): self.f = f; self.kw = kw
+class Pipe  (B): __ror__ = lambda self, x: self.f(x)
 class Map   (B): __ror__ = lambda self, x: map   (self.f, x)
 class Filter(B): __ror__ = lambda self, x: filter(self.f, x)
 
-# helpers
-def unit_tuple(x):
-    if isinstance(x, Iterable):
-        return x
-    return x,
-
-
-
 
 # extended
 class Reduce        (B): __ror__ = lambda self, x: reduce(self.f, x)
@@ -51,6 +43,7 @@ class ShellExec     (B): __ror__ = lambda self, x: subprocess.check_output(
 class PipeArgs      (B): __ror__ = lambda self, x: self.f(*x)
 class MapArgs       (B): __ror__ = lambda self, x: x | Map(lambda y: y | PipeArgs(self.f))
 class IsUnique      (B): __ror__ = lambda self, seq: len(seq) == len(set(seq if self.f is None else map(self.f, seq)))
+class Sorted        (B): __ror__ = lambda self, it: sorted(it, **self.kw)
 
 
 class Unique(B):
@@ -69,28 +62,14 @@ class ForEach(B):
     def __ror__(self, x):
         for e in x: self.f(e)
 
-# flat_map_fn = lambda kv: ((kv[0], x) for x in f(kv[1]))
-#         return self.flatMap(flat_map_fn, preservesPartitioning=True)
 
 class ThreadMap(B):
     def __ror__(self, it):
         with concurrent.futures.ThreadPoolExecutor() as pool:
             return pool.map(self.f, it) | Pipe(tuple)
 
+
 class ProcessMap(B):
     def __ror__(self, it):
         with concurrent.futures.ProcessPoolExecutor() as pool:
             return pool.map(self.f, it) | Pipe(tuple)
-
-
-
-# class Sorted        (B): __ror__ = lambda self, x: sorted(x, **self.kw)
-
-# shell = lambda x : subprocess.check_output(x, text=True).splitlines()
-# argto
-# class B:
-#     def __init__(self, f=None, **kw):
-#         self.f = f
-#         self.kw = kw # optional
-
-
